# xpip

Python package. Build. Install.

## Language

- **[简体中文](docs/zh/README.md)**

## Features

- **Quickly build and install Python package via [xpip-build](docs/xpip-build.md)**
- **Upload package to PyPI repository via [xpip-upload](docs/xpip-upload.md)**
- **Manage mirror via [xpip-mirror](docs/xpip-mirror.md)**
